#include "StdAfx.h"
#include "ChatRoomView.h"
#include "AutoLock.h"
#include "DuiDefine.h"
#include "ChatItem.h"

CChatRoomView::CChatRoomView(void)
{
	m_pRoomList = NULL;
}

CChatRoomView::~CChatRoomView(void)
{
    m_pRoomList = NULL;
}


void CChatRoomView::SetListControl( CFriendsUI* pRoomList )
{
	m_pRoomList = pRoomList;
}


void CChatRoomView::OnAdd( CChatRoom* pChatRoom )
{
    //check which code call this
    ASSERT(FALSE);  //lint !e527

	CAutoLock lock(&m_csChatRoomList);
	
	if(NULL == pChatRoom || NULL == m_pRoomList ) return;

	FriendListItemInfo info;
	info.folder = false;
	info.logo = GetAppDUIImgDir() + _T("\\main_profile_blank.png");
	info.nick_name = pChatRoom->m_strUserNames.c_str();
	info.description = pChatRoom->m_infoLastChatItem.strMsg;
	
	BOOL bGroup = pChatRoom->m_bGroup;

	if(!bGroup)
	{
		info.id = pChatRoom->m_strUserID.c_str();
	}

	Node* pNode = m_pRoomList->AddChattingRoomNode(info, pChatRoom->m_nRoomID, NULL);

	CButtonUI* log_button = static_cast<CButtonUI*>(m_pRoomList->paint_manager_.FindSubControlByName(pNode->data().list_elment_, kLogoButtonControlName));
	CLabelUI*  pLabProfile = static_cast<CLabelUI*>(m_pRoomList->paint_manager_.FindSubControlByName(pNode->data().list_elment_, _T("profile")));

	if (log_button != NULL && pLabProfile != NULL)
	{
		CDuiString strUserId = _T("");
		CDuiString strImage = _T("");

		if (bGroup)
		{
			strImage =GetAppDUIImgDir() + _T("\\img_main_chat_list_profile_nopic.png");
		} 
		else 
		{
			strUserId = pChatRoom->m_strUserID.c_str();
			strImage = GET_APP()->GetProfileImagePath(strUserId);
		}	

		log_button->SetBkImage(strImage);
		pLabProfile->SetTag((UINT_PTR)bGroup);
	}	
}

void CChatRoomView::OnUpdate( CChatRoom* pChatRoom , CChatRoomManager* pRoomManager)
{
    ASSERT(FALSE); //check which code call this
	CAutoLock lock(&m_csChatRoomList);

	if(NULL == pChatRoom || NULL == m_pRoomList ) return;

	Node* pNode = NULL;
	
	//update all room time
	for(int nIndex = 0; nIndex < m_pRoomList->GetRoot()->num_children(); nIndex++)
	{
		pNode = m_pRoomList->GetNodeByIndex(nIndex);
		int nRoomID = pNode->GetCompareData();

		CChatRoom* pRoom = pRoomManager->GetChatRoom(nRoomID);
		if(NULL == pRoom) continue;
		
		CLabelUI* date = static_cast<CLabelUI*>(m_pRoomList->paint_manager_.FindSubControlByName(pNode->data().list_elment_, _T("date")));
		if(date != NULL)
		{
			CTime tm = pRoom->m_updateTime;
			CString strTime = ParseChatTime(tm);
			date->SetText(strTime);
		}
	}

	//update target room 
	pNode = m_pRoomList->FindNodeByCompareData(pChatRoom->m_nRoomID);
	if(NULL == pNode) return;

	CString strBuf = _T("");
	FriendListItemInfo info;
	info.folder = false;
	info.logo = GET_APP()->GetProfileImagePath(pChatRoom->m_strUserID.c_str());
	info.nick_name = pChatRoom->m_strUserNames.c_str();
	ChatItemInfo &chatItemInfo = pChatRoom->m_infoLastChatItem;
}

CString CChatRoomView::ParseChatTime( CTime tmChat )
{
	CString strChatTime = tmChat.FormatGmt(_T("%Y.%m.%d"));
	CTime tmNow = CTime::GetCurrentTime();
	GetLocaleTime(&tmNow);
	CString strNowTime = tmNow.FormatGmt(_T("%Y.%m.%d"));
	CTimeSpan tmSpan= tmNow - tmChat;
	LONGLONG nSecond = tmSpan.GetTotalSeconds();

	if (strChatTime == strNowTime)
	{
		if (nSecond >= 0 && nSecond < 60)
		{
			nSecond = max(nSecond, 1);
			strChatTime.Format(_T("%d"), (INT)nSecond);
			strChatTime += LoadStringFromResource(IDS_STRING_SECOND_AGO);
		}
		else if (nSecond >= 60 && nSecond < 3600)
		{
			strChatTime.Format(_T("%d"), (INT)(nSecond/60));
			strChatTime += LoadStringFromResource(IDS_STRING_MINUTE_AGO); 
		}
		else if (nSecond >= 3600 && nSecond < 3600*24)
		{
			strChatTime = tmChat.FormatGmt(_T("%H:%M"));
		}
	}
	else
	{
		strChatTime = tmChat.FormatGmt(_T("%Y.%m.%d"));
	}

	return strChatTime;
}

void CChatRoomView::OnRemove( int nRoomID )
{

}

CString CChatRoomView::GetLastFileOrStickerMsg( const ChatItemInfo& chatItemInfo )
{
	CString strMyID = g_pMessengerActor->GetUserID();
	CString strFileOrStickerMsg = _T("");
	if (chatItemInfo.eMsgGB == CHAT_MSG_FTP )
	{
		if (!strMyID.Compare(chatItemInfo.strUserID))
		{
			strFileOrStickerMsg = LoadStringFromResource(IDS_STRING_SEND_FILE);
		}
		else{
			strFileOrStickerMsg = LoadStringFromResource(IDS_STRING_RECEIVE_FILE);
		}
	}
	else if (chatItemInfo.eMsgGB == CHAT_MSG_STICKER)
	{
		if (!strMyID.Compare(chatItemInfo.strUserID))
		{
			strFileOrStickerMsg = LoadStringFromResource(IDS_STRING_SEND_STICKER);
		}
		else{
			strFileOrStickerMsg = LoadStringFromResource(IDS_STRING_RECEIVE_STICKER);
		}

	}

	return strFileOrStickerMsg;

}
